from pymanga import pymanga, Sources

# Test example
manga_name = "Naruto"
chapter = 699

# Search for the manga using both sources
if __name__ == '__main__':
    manga_pages = pymanga.search(manga_name, chapter, sources=[Sources.MANGA_LIVRE])
    # Print the result
    print(manga_pages)


from enum import Enum
from pymanga.sources.mangalivre import MangaLivre
from pymanga.sources.muitomanga import MuitoManga

class Sources(Enum):
    MANGA_LIVRE = 'manga_livre'
    MUITO_MANGA = 'muito_manga'

class SourceFactory:
    _value_map = {
        Sources.MANGA_LIVRE: MangaLivre,
        Sources.MUITO_MANGA: MuitoManga
    }

    @staticmethod
    def get_source(value, manga_name, chapter):
        cls = SourceFactory._value_map[value]
        return cls(manga_name, chapter)


class pymanga:
    
    @staticmethod
    # Get mangas by sources
    def search(manga_name, chapter, **sources):
        result = []
        for source in sources['sources']:
            manga_downloader = SourceFactory.get_source(source, manga_name, chapter)
            pages = manga_downloader.search()
            result += pages
        
        return result




from setuptools import setup, find_packages

setup(
    name='pymangaj',
    version='0.1.1',
    description='Search and download mangas.',
    long_description='Search and download mangas from the internet.',
    author='Jean Jacques Barros',
    author_email='jjean.jacques10@gmail.com',
    url='https://github.com/jjeanjacques10/pymangaj',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
